package de.intevation.flys.importer;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;

import de.intevation.flys.model.Waterlevel;
import de.intevation.flys.model.WaterlevelQRange;


/** Has a Q and list of W,km values. */
public class ImportWaterlevelQRange {

    private static final Logger log =
        Logger.getLogger(ImportWaterlevelQRange.class);

    private Double q;

    private List<ImportWaterlevelValue> values;

    private WaterlevelQRange peer;


    public ImportWaterlevelQRange(Double q) {
        this.values = new ArrayList<ImportWaterlevelValue>();
        this.q      = q;
    }

    public void addValue(ImportWaterlevelValue value) {
        this.values.add(value);
    }

    public Double getQ() {
        return this.q;
    }

    public List<ImportWaterlevelValue> getValues() {
        return values;
    }

    public void storeDependencies(Waterlevel waterlevel) {
        log.info("store dependencies");

        WaterlevelQRange peer = getPeer(waterlevel);

        int i = 0;

        for (ImportWaterlevelValue value: values) {
            value.storeDependencies(peer);
            i++;
        }

        log.info("stored " + i + " waterlevel values");
    }


    public WaterlevelQRange getPeer(Waterlevel waterlevel) {
        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();
            Query query = session.createQuery(
                "from WaterlevelQRange where " +
                "   waterlevel=:waterlevel and " +
                "   q=:q"
            );

            query.setParameter("waterlevel", waterlevel);
            query.setParameter("q", q);

            List<WaterlevelQRange> qRanges = query.list();
            if (qRanges.isEmpty()) {
                peer = new WaterlevelQRange(waterlevel, q);
                session.save(peer);
            }
            else {
                peer = qRanges.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
